@@ -20,6 +20,7 @@ from .compat import (
     Iterable,
     Path,
     StringIO,
+    TimeoutError,
     fs_str,
     is_bytes,
     partialmethod,
@@ -194,11 +195,22 @@ def get_stream_results(cmd_instance, verbose, maxlen, spinner=None, stdout_allow
         stderr_line = stream_contents["stderr"]
         if not (stdout_line or stderr_line):
             break
+        last_changed = 0
+        display_line = ""
         for stream_name in stream_contents.keys():
             if stream_contents[stream_name] and stream_name in stream_results:
                 line = stream_contents[stream_name]
                 stream_results[stream_name].append(line)
-                display_line = fs_str("{0}".format(line))
+                display_line = (
+                    fs_str("{0}".format(line))
+                    if stream_name == "stderr"
+                    else display_line
+                )
+                if display_line and last_changed > 10:
+                    last_changed = 0
+                    display_line = ""
+                elif display_line:
+                    last_changed += 1
                 if len(display_line) > maxlen:
                     display_line = "{0}...".format(display_line[:maxlen])
                 if verbose:
@@ -256,18 +268,15 @@ def _create_subprocess(
         c = _spawn_subprocess(
             cmd, env=env, block=block, cwd=cwd, combine_stderr=combine_stderr
         )
-    except Exception as exc:
+    except Exception as exc:  # pragma: no cover
         import traceback
 
-        formatted_tb = "".join(
-            traceback.format_exception(*sys.exc_info())
-        )  # pragma: no cover
-        sys.stderr.write(  # pragma: no cover
-            "Error while executing command %s:"
-            % to_native_string(" ".join(cmd._parts))  # pragma: no cover
-        )  # pragma: no cover
-        sys.stderr.write(formatted_tb)  # pragma: no cover
-        raise exc  # pragma: no cover
+        formatted_tb = "".join(traceback.format_exception(*sys.exc_info()))
+        sys.stderr.write(
+            "Error while executing command %s:" % to_native_string(" ".join(cmd._parts))
+        )
+        sys.stderr.write(formatted_tb)
+        raise exc
     if not block:
         c.stdin.close()
         spinner_orig_text = ""
@@ -290,9 +299,10 @@ def _create_subprocess(
     else:
         try:
             c.out, c.err = c.communicate()
-        except (SystemExit, TimeoutError):
+        except (SystemExit, KeyboardInterrupt, TimeoutError):  # pragma: no cover
             c.terminate()
             c.out, c.err = c.communicate()
+            raise
     if not block:
         c.wait()
     c.out = to_text("{0}".format(c.out)) if c.out else fs_str("")
@@ -371,7 +381,7 @@ def run(
             spinner=sp,
             combine_stderr=combine_stderr,
             start_text=start_text,
-            write_to_stdout=True,
+            write_to_stdout=write_to_stdout,
         )
 
 
